==> haskell-raw-strings-qq-1.1-204-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-IUb6b8KQkfHI1f5yeSEkz6
key:                  raw-strings-qq-1.1-IUb6b8KQkfHI1f5yeSEkz6
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  021ecfd53ec62a6b7879863d09806133
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-9.0.2/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-raw-strings-qq
hs-libraries:         HSraw-strings-qq-1.1-IUb6b8KQkfHI1f5yeSEkz6
depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-raw-strings-qq-1.1-223-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
key:                  raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  ef101dbb9a088e55c182716e96b2e370
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-9.2.8/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-raw-strings-qq
hs-libraries:         HSraw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
depends:              base-4.16.4.0 template-haskell-2.18.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
